@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_Multimedia_src_multimedia_qtmultimedia_config_p_h_H
+#define QT_FEATURES_Multimedia_src_multimedia_qtmultimedia_config_p_h_H
+
 #define QT_FEATURE_pipewire -1
 
 #define QT_FEATURE_pipewire_screencapture -1
@@ -52,3 +55,5 @@
 
 #define QT_FEATURE_ffmpeg_stubs -1
 
+
+#endif // QT_FEATURES_Multimedia_src_multimedia_qtmultimedia_config_p_h_H
